/*
 * Unofficial EZX Native Software Development Kit
 * Copyright (C) 2006 Ketut P. Kumajaya <kumajaya@bluebottle.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Further, this software is distributed without any warranty that it is
 * free of the rightful claim of any third person regarding infringement
 * or the like.  Any license provided herein, whether implied or
 * otherwise, applies only to this software file.  Patent licenses, if
 * any, provided herein do not apply to combinations of this program with
 * other software, or any other product whatsoever.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#if !defined(__UTIL_PROGRESSBAR_H__)
#define __UTIL_PROGRESSBAR_H__

#include <qframe.h>

class UTIL_ProgressBar : public QFrame
{
    Q_OBJECT
	
public:
    UTIL_ProgressBar( QWidget *parent=0, const char *name=0, WFlags f=0 );
    UTIL_ProgressBar( int totalSteps, QWidget *parent=0, const char *name=0,
		  WFlags f=0 );

    int		totalSteps() const;
    int		progress()   const;

    QSize	sizeHint() const;
    QSizePolicy sizePolicy() const;
    QSize	minimumSizeHint() const;

    void	setCenterIndicator( bool on );
    bool	centerIndicator() const;

    void        setIndicatorFollowsStyle( bool );
    bool	indicatorFollowsStyle() const;

    void	show();

public slots:
    void	reset();
    virtual void setTotalSteps( int totalSteps );
    virtual void setProgress( int progress );

protected:
    void	drawContents( QPainter * );
    void	drawContentsMask( QPainter * );
    virtual bool setIndicator( QString & progress_str, int progress,
			       int totalSteps );
    void styleChange( QStyle& );

private:
    int		total_steps;
    int		progress_val;
    int		percentage;
    QString	progress_str;
    bool        center_indicator;
    bool        auto_indicator;
    void         initFrame();

private:	// Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
    UTIL_ProgressBar( const UTIL_ProgressBar & );
    UTIL_ProgressBar &operator=( const UTIL_ProgressBar & );
#endif
};


inline int UTIL_ProgressBar::totalSteps() const
{
    return total_steps;
}

inline int UTIL_ProgressBar::progress() const
{
    return progress_val;
}

inline bool UTIL_ProgressBar::centerIndicator() const
{
    return center_indicator;
}

inline bool UTIL_ProgressBar::indicatorFollowsStyle() const
{
    return auto_indicator;
}

#endif // __UTIL_PROGRESSBAR_H__
