/*
 * Unofficial EZX Native Software Development Kit
 * Copyright (C) 2006 Ketut P. Kumajaya <kumajaya@bluebottle.com>
 * Thank you to the pioneer, Sam Revitch <samr7@cs.washington.edu>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * Further, this software is distributed without any warranty that it is
 * free of the rightful claim of any third person regarding infringement
 * or the like.  Any license provided herein, whether implied or
 * otherwise, applies only to this software file.  Patent licenses, if
 * any, provided herein do not apply to combinations of this program with
 * other software, or any other product whatsoever.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#if !defined(__UTIL_PROGRESSDIALOG_H__)
#define __UTIL_PROGRESSDIALOG_H__

#include <qsemimodal.h>
#include <qlabel.h>
#include <ezxutilpushbutton.h>
#include <ezxutilprogressbar.h>

class QTimer;

class UTIL_ProgressDialog : public QSemiModal
{
    Q_OBJECT

public:
    UTIL_ProgressDialog( QWidget *parent=0, const char *name=0, bool modal=FALSE,
		     WFlags f=0 );
    UTIL_ProgressDialog( const QString& labelText, const QString &cancelButtonText,
		     int totalSteps, QWidget *parent=0, const char *name=0,
		     bool modal=FALSE, WFlags f=0 );
   ~UTIL_ProgressDialog();

    void	setLabel( QLabel * );
    void	setCancelButton( UTIL_PushButton * );
    void	setBar( UTIL_ProgressBar * );

    bool	wasCancelled() const;

    int		totalSteps() const;
    int		progress()   const;

    QSize	sizeHint() const;

    QString     labelText() const;

    void setAutoReset( bool b );
    bool autoReset() const;
    void setAutoClose( bool b );
    bool autoClose() const;

public slots:
    void	cancel();
    void	reset();
    void	setTotalSteps( int totalSteps );
    void	setProgress( int progress );
    void	setLabelText( const QString &);
    void	setCancelButtonText( const QString &);

    void	setMinimumDuration( int ms );
public:
    int		minimumDuration() const;

signals:
    void	cancelled();

protected:
    void	resizeEvent( QResizeEvent * );
    void	closeEvent( QCloseEvent * );
    void	styleChange( QStyle& );
    void	showEvent( QShowEvent *e );

protected slots:
    void	forceShow();
    
private:
    void	   init( QWidget *creator, const QString& lbl, const QString &canc,
		         int totstps);
    void	   center();
    void	   layout();
    QLabel	  *label()  const;
    UTIL_ProgressBar  *bar()    const;

private:	// Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
    UTIL_ProgressDialog( const UTIL_ProgressDialog & );
    UTIL_ProgressDialog &operator=( const UTIL_ProgressDialog & );
#endif
};

#endif // __UTIL_PROGRESSDIALOG_H__
